==> nextcloud-21.0.8p0.tgz: nextcloud/apps/weather_status/l10n/el.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Άγνωστη διεύθυνση",
    "No result." : "Κανένα αποτέλεσμα.",
    "Malformed JSON data." : "Κακή μορφή δεδομένων JSON.",
    "Error" : "Σφάλμα",
    "Weather status" : "Κατάσταση καιρού",
    "Weather status in your dashboard" : "Κατάσταση καιρού στον πίνακα ελέγχου",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Η κατάσταση του καιρού ενσωματώνεται στην εφαρμογή Πίνακας ελέγχου.\n    Η θέση του χρήστη μπορεί να προσδιοριστεί αυτόματα ή να καθοριστεί χειροκίνητα. Στη συνέχεια εμφανίζεται μια πρόβλεψη 6 ωρών.\n    Αυτή η κατάσταση μπορεί επίσης να ενσωματωθεί σε άλλα μέρη όπως στην εφαρμογή Ημερολόγιο.",
    "Detect location" : "Εντόπιση τοποθεσίας",
    "Set custom address" : "Ορισμός προσαρμοσμένης διεύθυνσης",
    "Favorites" : "Αγαπημένα",
    "More weather for {adr}" : "Περισσότερος καιρός για {adr}",
    "Loading weather" : "Φόρτωση καιρού",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add as favorite" : "Προσθήκη ως αγαπημένο",
    "You are not logged in." : "Δεν έχετε συνδεθεί.",
    "There was an error getting the weather status information." : "Παρουσιάστηκε σφάλμα κατά τη λήψη των πληροφοριών σχετικά με την κατάσταση καιρού.",
    "No weather information found" : "Δεν βρέθηκαν πληροφορίες για τον καιρό",
    "Location not found" : "Δεν βρέθηκε η τοποθεσία",
    "There was an error setting the location address." : "Παρουσιάστηκε σφάλμα κατά τον καθορισμό της διεύθυνσης τοποθεσίας.",
    "There was an error setting the location." : "Παρουσιάστηκε σφάλμα κατά τη ρύθμιση της τοποθεσίας.",
    "There was an error saving the mode." : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση της λειτουργίας.",
    "There was an error using personal address." : "Παρουσιάστηκε σφάλμα κατά τη χρήση της προσωπικής διεύθυνσης.",
    "Set location for weather" : "Ορισμός τοποθεσίας καιρού",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Η κατάσταση καιρού ενσωματώνεται στην εφαρμογή Πίνακας ελέγχου.\n    Η θέση του χρήστη μπορεί να προσδιοριστεί αυτόματα ή να καθοριστεί χειροκίνητα. Στη συνέχεια εμφανίζεται μια πρόβλεψη 6 ωρών.\n    Αυτή η κατάσταση μπορεί επίσης να ενσωματωθεί σε άλλα μέρη όπως στην εφαρμογή Ημερολόγιο.",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Καθαρός ουρανός στις {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Συννεφιά στις {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Αίθρια ημέρα στις {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Αίθρια νύχτα {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Μερικώς νεφελώδης στις {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Ομιχλώδης στις {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Ελαφρά βροχόπτωση στις {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Βροχή στις {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Δυνατή βροχή στις {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Καταιονισμός στις {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Ελαφρύς καταιονισμός στις {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Βαρύς καταιονισμός στις {time}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.1.tgz: nextcloud/apps/weather_status/l10n/el.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Άγνωστη διεύθυνση",
    "No result." : "Κανένα αποτέλεσμα.",
    "Malformed JSON data." : "Κακή μορφή δεδομένων JSON.",
    "Error" : "Σφάλμα",
    "Weather status" : "Κατάσταση καιρού",
    "Weather status in your dashboard" : "Κατάσταση καιρού στον πίνακα ελέγχου",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Η κατάσταση του καιρού ενσωματώνεται στην εφαρμογή Πίνακας ελέγχου.\n    Η θέση του χρήστη μπορεί να προσδιοριστεί αυτόματα ή να καθοριστεί χειροκίνητα. Στη συνέχεια εμφανίζεται μια πρόβλεψη 6 ωρών.\n    Αυτή η κατάσταση μπορεί επίσης να ενσωματωθεί σε άλλα μέρη όπως στην εφαρμογή Ημερολόγιο.",
    "Detect location" : "Εντόπιση τοποθεσίας",
    "Set custom address" : "Ορισμός προσαρμοσμένης διεύθυνσης",
    "Favorites" : "Αγαπημένα",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Καθαρός ουρανός στις {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Συννεφιά στις {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Αίθρια ημέρα στις {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Αίθρια νύχτα {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Μερικώς νεφελώδης στις {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Ομιχλώδης στις {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Ελαφρά βροχόπτωση στις {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Βροχή στις {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Δυνατή βροχή στις {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Καταιονισμός στις {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Ελαφρύς καταιονισμός στις {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Βαρύς καταιονισμός στις {time}",
    "More weather for {adr}" : "Περισσότερος καιρός για {adr}",
    "Loading weather" : "Φόρτωση καιρού",
    "Set location for weather" : "Ορισμός τοποθεσίας καιρού",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add as favorite" : "Προσθήκη ως αγαπημένο",
    "You are not logged in." : "Δεν έχετε συνδεθεί.",
    "There was an error getting the weather status information." : "Παρουσιάστηκε σφάλμα κατά τη λήψη των πληροφοριών σχετικά με την κατάσταση καιρού.",
    "No weather information found" : "Δεν βρέθηκαν πληροφορίες για τον καιρό",
    "Location not found" : "Δεν βρέθηκε η τοποθεσία",
    "There was an error setting the location address." : "Παρουσιάστηκε σφάλμα κατά τον καθορισμό της διεύθυνσης τοποθεσίας.",
    "There was an error setting the location." : "Παρουσιάστηκε σφάλμα κατά τη ρύθμιση της τοποθεσίας.",
    "There was an error saving the mode." : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση της λειτουργίας.",
    "There was an error using personal address." : "Παρουσιάστηκε σφάλμα κατά τη χρήση της προσωπικής διεύθυνσης.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Η κατάσταση καιρού ενσωματώνεται στην εφαρμογή Πίνακας ελέγχου.\n    Η θέση του χρήστη μπορεί να προσδιοριστεί αυτόματα ή να καθοριστεί χειροκίνητα. Στη συνέχεια εμφανίζεται μια πρόβλεψη 6 ωρών.\n    Αυτή η κατάσταση μπορεί επίσης να ενσωματωθεί σε άλλα μέρη όπως στην εφαρμογή Ημερολόγιο."
},
"nplurals=2; plural=(n != 1);");
